fn advance_position(
position: OriginZeroLine,
axis_is_reversed: bool,
) -> OriginZeroLineExpand description
Advances the cursor by one track in the active search direction.
fn advance_position(
position: OriginZeroLine,
axis_is_reversed: bool,
) -> OriginZeroLineAdvances the cursor by one track in the active search direction.