clamp_span_to_limited_grid

Function clamp_span_to_limited_grid 

fn clamp_span_to_limited_grid(
    span: Line<OriginZeroLine>,
    min_line: i16,
    max_line: i16,
) -> Line<OriginZeroLine>
Clamp a placement into the limited grid, preserving a span of at least 1 track. Items placed outside of the limited grid are clamped into it.

See: https://www.w3.org/TR/css-grid-1/#overlarge-grids