fn mirror_horizontal_span(
span: Line<OriginZeroLine>,
explicit_col_count: u16,
) -> Line<OriginZeroLine>Expand description
Mirrors a horizontal span around the explicit grid width.
fn mirror_horizontal_span(
span: Line<OriginZeroLine>,
explicit_col_count: u16,
) -> Line<OriginZeroLine>Mirrors a horizontal span around the explicit grid width.